**Example 1: 补充手机号信息**



Input: 

```
tccli cpdp AddFlexPhoneNo --cli-unfold-argument  \
    --PayeeId 1529657731805986816 \
    --PhoneNo 13412341234
```

Output: 
```
{
    "Response": {
        "ErrCode": "SUCCESS",
        "ErrMessage": "成功",
        "Result": null,
        "RequestId": "8ffecac1-2d89-43a9-9075-a985442ef466"
    }
}
```

